@@ -7,9 +7,11 @@
 mod constants;
 mod factorial;
 pub mod fee;
-mod ffi;
 mod legendre;
 mod types;
 
 #[cfg(feature = "python")]
 mod python;
+
+#[cfg(test)]
+mod jones_test;
